@@ -1,14 +1,16 @@
 
 __name__ = 'job_client_redis'
-name_url = __name__.replace('_', '-')
+name_url = 'job-client-py-redis'
 
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 __description__ = 'redis client in for jupyter-observablehq-bridge'
 __long_description__ = 'See repo README'
 __author__ = 'jupyter-observablehq-bridge'
 __author_email__ = 'olivier.borderies@gmail.com'
-__url__ = 'https://github.com/{}/{}'.format(__author__,
-                                            name_url)
+__url__ = 'https://github.com/{}/{}'.format(
+    __author__,
+    name_url
+)
 __download_url__ = 'https://github.com/{}/{}/tarball/{}'.format(
     __author__,
     name_url,
@@ -26,4 +28,3 @@ __include_package_data__ = True
 __package_data__ = {}
 __zip_safe__ = False
 __entry_points__ = {}
-
